/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 * 
 * Copyright 1997-2007 Sun Microsystems, Inc. All rights reserved.
 * 
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common Development
 * and Distribution License("CDDL") (collectively, the "License").  You
 * may not use this file except in compliance with the License. You can obtain
 * a copy of the License at https://glassfish.dev.java.net/public/CDDL+GPL.html
 * or glassfish/bootstrap/legal/LICENSE.txt.  See the License for the specific
 * language governing permissions and limitations under the License.
 * 
 * When distributing the software, include this License Header Notice in each
 * file and include the License file at glassfish/bootstrap/legal/LICENSE.txt.
 * Sun designates this particular file as subject to the "Classpath" exception
 * as provided by Sun in the GPL Version 2 section of the License file that
 * accompanied this code.  If applicable, add the following below the License
 * Header, with the fields enclosed by brackets [] replaced by your own
 * identifying information: "Portions Copyrighted [year]
 * [name of copyright owner]"
 * 
 * Contributor(s):
 * 
 * If you wish your version of this file to be governed by only the CDDL or
 * only the GPL Version 2, indicate your decision by adding "[Contributor]
 * elects to include this software in this distribution under the [CDDL or GPL
 * Version 2] license."  If you don't indicate a single choice of license, a
 * recipient has the option to distribute your version of this file under
 * either the CDDL, the GPL Version 2 or to extend the choice of license to
 * its licensees as provided above.  However, if you add GPL Version 2 code
 * and therefore, elected the GPL Version 2 license, then the option applies
 * only if the new code is made subject to such option by the copyright
 * holder.
 */
package org.glassfish.scripting.jruby;

import com.sun.grizzly.tcp.http11.GrizzlyRequest;
import com.sun.grizzly.tcp.http11.GrizzlyResponse;
import org.glassfish.scripting.jruby.monitor.JRubyHttpProbeProvider;
import org.glassfish.scripting.jruby.monitor.JRubyMonitorListner;
import org.glassfish.scripting.jruby.monitor.JRubyProbeProvider;
import org.glassfish.scripting.jruby.monitor.JRubyRuntimePoolProvider;

/**
 * This interface introduces certain redundancies but it hides Probe infrastructure from
 * the RackGrizzlyAdapter.
 *
 * JRuby monitoring listner interface. This interface is used by the RackGrizzlyAdapter
 * to update the events.
 *
 * @author Vivek Pandey
 */
public class JRubyMonitorListnerImpl implements JRubyMonitorListner {

    private final JRubyProbeProvider jrubyProbeProvier;
    private final JRubyRuntimePoolProvider jRubyRuntimePoolProvider;
    private final JRubyHttpProbeProvider jrubyHttpProbeProvider
            ;

    public JRubyMonitorListnerImpl() {
        this.jrubyProbeProvier = new JRubyProbeProvider();
        this.jRubyRuntimePoolProvider = new JRubyRuntimePoolProvider();
        this.jrubyHttpProbeProvider = new JRubyHttpProbeProvider();
    }

    @Override
    public void started(String appName, String appType, String environment, String jrubyVersion) {
        jrubyProbeProvier.jrubyModuleStartedEvent(appName, appType, environment, jrubyVersion);
    }

    @Override
    public void stopped(String appName, String appType, String environment) {
        jrubyProbeProvier.jrubyModuleStoppedEvent(appName, appType, environment);
    }

    @Override
    public void runtimePoolStartEvent(String appName, int hardMinimum, int hardMaximum,
                                      int activeRuntimes, int queueSize,
                                      int queueUpThreshold, int queueDownThreshold,
                                      int newThreshold) {
        jRubyRuntimePoolProvider.runtimePoolStartEvent(appName, hardMinimum, hardMaximum,
                activeRuntimes, queueSize, queueUpThreshold,
                queueDownThreshold, newThreshold);
    }

    @Override
    public void runtimePoolUpdateEvent(String appName, int activeRuntimes, int queueSize,
                                       int queueUpThreshold, int queueDownThreshold,
                                       int newThreshold) {
        jRubyRuntimePoolProvider.runtimePoolUpdateEvent(appName, activeRuntimes, queueSize,
                queueUpThreshold, queueDownThreshold, newThreshold);
    }

    @Override
    public void requestStartEvent(GrizzlyRequest request, GrizzlyResponse response) {
        jrubyHttpProbeProvider.requestStartEvent(request, response);
    }

    @Override
    public void requestEndEvent(GrizzlyRequest request, GrizzlyResponse response) {
        jrubyHttpProbeProvider.requestEndEvent(request, response);
    }
}
